@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009-2011 Petri Lehtinen <petri@digip.org>
+ * Copyright (c) 2009-2012 Petri Lehtinen <petri@digip.org>
  *
  * Jansson is free software; you can redistribute it and/or modify
  * it under the terms of the MIT license. See LICENSE for details.
@@ -24,6 +24,8 @@
 #include <fcntl.h>  /* for _O_BINARY */
 #endif
 
+#define l_isspace(c) ((c) == ' ' || (c) == '\n' || (c) == '\r' || (c) == '\t')
+
 static int getenv_int(const char *name)
 {
     char *value, *end;
@@ -47,14 +49,14 @@ static const char *strip(char *str)
 {
     size_t length;
     char *result = str;
-    while(*result && isspace(*result))
+    while(*result && l_isspace(*result))
         result++;
 
     length = strlen(result);
     if(length == 0)
         return result;
 
-    while(isspace(result[length - 1]))
+    while(l_isspace(result[length - 1]))
         result[--length] = '\0';
 
     return result;
